@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.90 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: amenu.c,v 1.91 2009/06/26 16:58:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -43,23 +43,32 @@
 /***************************************************************/
 
 static auto_mark_t	ls_auto_mark[LS_MBR_MAX_N][AUTO_MARK_MAX_N];
+check_memory_def( check_memory_amenu_c_ls_auto_mark )
 static bool_t	ls_flg_ena_auto_mark[AUTO_MARK_MAX_N];
+check_memory_def( check_memory_amenu_c_ls_flg_ena_auto_mark )
 
 static auto_mark_t	clip_board_large[LS_MBR_MAX_N];
+check_memory_def( check_memory_amenu_c_clip_board_large )
 static auto_mark_t	clip_board_small;
+check_memory_def( check_memory_amenu_c_clip_board_small )
 
 static auto_mark_appoint_item_t	clip_board_large_item
 		[LS_MBR_MAX_N][AUTO_MARK_APPOINT_ITEM_MAX_N];
+check_memory_def( check_memory_amenu_c_clip_board_large_item )
 static auto_mark_appoint_item_t	clip_board_small_item
 		[AUTO_MARK_APPOINT_ITEM_MAX_N];
+check_memory_def( check_memory_amenu_c_clip_board_small_item )
 
 static char	msg_ttl_auto_mark[AUTO_MARK_MAX_N]
 		[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
+check_memory_def( check_memory_amenu_c_msg_ttl_auto_mark )
 static char	clip_board_ttl
 		[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
+check_memory_def( check_memory_amenu_c_clip_board_ttl )
 
 static long	auto_mark_cur_n;
 static mbr_t	*g_sel_mbr;
+check_memory_def( check_memory_amenu_c_auto_mark_cur_n )
 
 static auto_mark_t	dflt_auto_mark_fight = {
 	AUTO_MARK_TRGT_MNSTR,
@@ -160,9 +169,12 @@ static auto_mark_t	dflt_auto_mark_clear = {
 	FLG_AUTO_MARK_EDIT_PRIORITY,
 };
 
+check_memory_def( check_memory_amenu_c_dflt_auto_mark_fight )
+
 static auto_mark_appoint_item_t	auto_mark_appoint_item
 		[LS_MBR_MAX_N][AUTO_MARK_MAX_N]
 		[AUTO_MARK_APPOINT_ITEM_MAX_N];
+check_memory_def( check_memory_amenu_c_auto_mark_appoint_item )
 
 static auto_mark_appoint_item_t	auto_mark_appoint_item_dflt
 		[AUTO_MARK_APPOINT_ITEM_MAX_N] = {
@@ -225,6 +237,7 @@ static auto_mark_appoint_item_t	auto_mark_appoint_item_dflt
 
 	{ FACE_MJR_NULL, FACE_MNR_NULL, FALSE },
 };
+check_memory_def( check_memory_amenu_c_auto_mark_appoint_item_dflt )
 
 /***************************************************************/
 
@@ -3457,3 +3470,35 @@ auto_mark_appoint_item_t	*get_ls_auto_mark_appoint_item(
 
 	return( auto_mark_appoint_item[ls_mbr_n][n] );
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_amenu_c( void )
+{
+	check_memory( check_memory_amenu_c_ls_auto_mark,
+			"amenu.c: ls_auto_mark" );
+	check_memory( check_memory_amenu_c_ls_flg_ena_auto_mark,
+			"amenu.c: ls_flg_ena_auto_mark" );
+	check_memory( check_memory_amenu_c_clip_board_large,
+			"amenu.c: clip_board_large" );
+	check_memory( check_memory_amenu_c_clip_board_small,
+			"amenu.c: clip_board_small" );
+	check_memory( check_memory_amenu_c_clip_board_large_item,
+			"amenu.c: clip_board_large_item" );
+	check_memory( check_memory_amenu_c_clip_board_small_item,
+			"amenu.c: clip_board_small_item" );
+	check_memory( check_memory_amenu_c_msg_ttl_auto_mark,
+			"amenu.c: msg_ttl_auto_mark" );
+	check_memory( check_memory_amenu_c_clip_board_ttl,
+			"amenu.c: clip_board_ttl" );
+	check_memory( check_memory_amenu_c_auto_mark_cur_n,
+			"amenu.c: auto_mark_cur_n" );
+	check_memory( check_memory_amenu_c_dflt_auto_mark_fight,
+			"amenu.c: dflt_auto_mark_fight" );
+	check_memory( check_memory_amenu_c_auto_mark_appoint_item,
+			"amenu.c: auto_mark_appoint_item" );
+	check_memory( check_memory_amenu_c_auto_mark_appoint_item_dflt,
+			"amenu.c: auto_mark_appoint_item_dflt" );
+}
