@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.h,v 1.37 2008/09/07 11:31:27 bowkenken Exp $
+* $Id: curs.h,v 1.40 2009/06/21 14:55:30 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CURS_H
@@ -38,7 +38,12 @@
 #include	"extern.h"
 #include	"msg.h"
 
-#if	defined( HAVE_NCURSES_H )
+#if	defined( HAVE_NCURSESW_H )
+# include	<ncursesw.h>
+# ifndef	COLOR_WHITE
+#  include	"curs-def.h"
+# endif
+#elif	defined( HAVE_NCURSES_H )
 # include	<ncurses.h>
 # ifndef	COLOR_WHITE
 #  include	"curs-def.h"
@@ -94,6 +99,11 @@ typedef enum {
 	CURS_ATTR_N_MBR_5,
 	CURS_ATTR_N_MBR_6,
 
+	CURS_ATTR_N_HEAT,
+	CURS_ATTR_N_COLD,
+	CURS_ATTR_N_MIND,
+	CURS_ATTR_N_ACID,
+
 	CURS_ATTR_MAX_N,
 
 	CURS_ATTR_N_MAP_NORMAL = CURS_ATTR_N_NORMAL,
