@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gf-town.c,v 1.2 2009/01/04 00:24:52 bowkenken Exp $
+* $Id: gf-town.c,v 1.3 2009/06/26 16:58:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -321,3 +321,11 @@ void	back_up_town_ptn( void )
 {
 	rename_back_up_file( path_name_town_ptn );
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_gf_town_c( void )
+{
+}
