@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: item.h,v 1.100 2009/02/07 00:35:20 bowkenken Exp $
+* $Id: item.h,v 1.101 2009/06/01 05:05:04 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	ITEM_H
@@ -52,13 +52,20 @@
 
 /* ƥ̾κʸ */
 #define	ITEM_NAME_MAX_LEN	60
+#define	ITEM_NAME_MAX_BYTE	\
+	(ITEM_NAME_MAX_LEN * CHAR_MAX_LEN_UTF_8)
+
 /* ʤΥƥ̾κʸ */
 #define	ITEM_ART_NAME_MAX_LEN	(ITEM_NAME_MAX_LEN + 16)
+#define	ITEM_ART_NAME_MAX_BYTE	\
+	(ITEM_ART_NAME_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 
 /* ʪΥȥκ粻 */
 #define	SCROLL_TTL_SYLLABLE_MAX_N	4
 /* ʪΥȥκʸ */
 #define	SCROLL_TTL_MAX_LEN	50
+#define	SCROLL_TTL_MAX_BYTE	\
+	(SCROLL_TTL_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 
 /* ţʿܿ */
 #define	SPIKE_AVE_N	11
@@ -1169,7 +1176,7 @@ typedef struct {
 	n_msg_idx_t	ttl_idx[SCROLL_TTL_SYLLABLE_MAX_N + 1];
 
 	/* ȥ */
-	char	ttl[SCROLL_TTL_MAX_LEN + 1];
+	char	ttl[SCROLL_TTL_MAX_BYTE + 1];
 
 	/* ̺ѥե饰 */
 	bool_t	flg_identified;
@@ -1468,11 +1475,11 @@ typedef struct item_t {
 	bool_t	flg_garbage;
 
 	/* ̾ */
-	char	name[ITEM_NAME_MAX_LEN + 1];
+	char	name[ITEM_NAME_MAX_BYTE + 1];
 	/* ̾ */
-	char	art_name[ITEM_ART_NAME_MAX_LEN + 1];
+	char	art_name[ITEM_ART_NAME_MAX_BYTE + 1];
 	/* ̾ */
-	char	alias[ITEM_NAME_MAX_LEN + 1];
+	char	alias[ITEM_NAME_MAX_BYTE + 1];
 
 	/*  */
 	item_kind_t	kind;
