@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.c,v 1.216 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: menu.c,v 1.220 2009/07/11 14:22:20 bowkenken Exp $
 ***************************************************************/
 
 #define	MENU_C
@@ -42,8 +42,12 @@ static bool_t	g_flg_space_select;
 static bool_t	g_flg_menu_dflt;
 static bool_t	g_flg_chk_menu;
 static bool_t	g_flg_chk_short_key;
+static long	g_sel_menu_accel_key;
+static bool_t	g_flg_move_crsr_dflt;
+check_memory_def( check_memory_menu_c_g_nest_flg_executing_menu )
 
 static ask_t	g_sel_ask;
+check_memory_def( check_memory_menu_c_g_sel_ask )
 
 static char	*menu_kind_ls[] = {
 	/* ȥ */
@@ -72,8 +76,10 @@ static char	*menu_kind_ls[] = {
 
 	NULL,
 };
+check_memory_def( check_memory_menu_c_menu_kind_ls )
 
 menu_t	dummy_menu_close_menu;
+check_memory_def( check_memory_menu_c_dummy_menu_close_menu )
 
 /***************************************************************
 * ե󥯥󡦥
@@ -82,6 +88,7 @@ menu_t	dummy_menu_close_menu;
 #define	MENU_FUNC_MAX_N_PER_PAGE	10
 
 static char	g_func[FUNC_KEY_MAX + 1][MACRO_MAX_LEN + 1];
+check_memory_def( check_memory_menu_c_g_func )
 
 /* ǥեȤΥե󥯥󡦥 */
 typedef struct {
@@ -187,8 +194,10 @@ static func_short_key_t
 	{ NULL, NULL },	/* F79 */
 	{ NULL, NULL },	/* F80 */
 };
+check_memory_def( check_memory_menu_c_g_ls_func_short_key )
 
 static bool_t	g_flg_dup_short_key[256];
+check_memory_def( check_memory_menu_c_g_flg_dup_short_key )
 
 /**/
 
@@ -199,9 +208,11 @@ static bool_t	g_flg_dup_short_key[256];
 void	init_var_menu( void )
 {
 	g_nest_flg_executing_menu = make_nest_flg();
+	g_sel_menu_accel_key = '\0';
 
 	set_flg_space_select( FALSE );
 	set_flg_menu_dflt( TRUE );
+	set_flg_move_crsr_dflt( FALSE );
 }
 
 /**/
@@ -881,6 +892,18 @@ void	sel_menu_clr( draw_menu_t *data )
 /**/
 
 menu_t	*sel_menu( menu_t *p, menu_t *dflt )
+{
+	menu_t	*res;
+
+	res = sel_menu_sub( p, dflt );
+	g_sel_menu_accel_key = '\0';
+
+	return res;
+}
+
+/**/
+
+menu_t	*sel_menu_sub( menu_t *p, menu_t *dflt )
 {
 	static draw_menu_t	data;
 	menu_t	*tmp_p;
@@ -960,6 +983,8 @@ menu_t	*sel_menu( menu_t *p, menu_t *dflt )
 
 		dx = 0;
 		dy = 0;
+
+		g_sel_menu_accel_key = data.ls[sel_n]->accel_key;
 		key = get_key( g_flg_clr_key_buf_menu );
 
 		switch( key ){
@@ -1695,3 +1720,45 @@ bool_t	set_flg_space_select( bool_t flg )
 
 /**/
 
+long	get_sel_menu_accel_key( void )
+{
+	return g_sel_menu_accel_key;
+}
+
+/**/
+
+bool_t	get_flg_move_crsr_dflt( void )
+{
+	return g_flg_move_crsr_dflt;
+}
+
+/**/
+
+bool_t	set_flg_move_crsr_dflt( bool_t flg )
+{
+	g_flg_move_crsr_dflt = flg;
+
+	return g_flg_move_crsr_dflt;
+}
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_menu_c( void )
+{
+	check_memory( check_memory_menu_c_g_nest_flg_executing_menu,
+			"menu.c: g_nest_flg_executing_menu" );
+	check_memory( check_memory_menu_c_g_sel_ask,
+			"menu.c: g_sel_ask" );
+	check_memory( check_memory_menu_c_menu_kind_ls,
+			"menu.c: menu_kind_ls" );
+	check_memory( check_memory_menu_c_dummy_menu_close_menu,
+			"menu.c: dummy_menu_close_menu" );
+	check_memory( check_memory_menu_c_g_func,
+			"menu.c: g_func" );
+	check_memory( check_memory_menu_c_g_ls_func_short_key,
+			"menu.c: g_ls_func_short_key" );
+	check_memory( check_memory_menu_c_g_flg_dup_short_key,
+			"menu.c: g_flg_dup_short_key" );
+}
