@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: misc.c,v 1.46 2009/02/01 10:22:22 bowkenken Exp $
+* $Id: misc.c,v 1.47 2009/06/26 16:58:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -40,7 +40,9 @@
 /* μ */
 
 static long	randm_seed = 1;
+check_memory_def( check_memory_misc_c_randm_seed )
 static long	randm_seed_gui = 1;
+check_memory_def( check_memory_misc_c_randm_seed_gui )
 
 /***************************************************************
 * ƥåѿꥻå
@@ -604,3 +606,14 @@ void	free_mem( void *p )
 		free( p );
 }
 
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_misc_c( void )
+{
+	check_memory( check_memory_misc_c_randm_seed,
+			"misc.c: randm_seed" );
+	check_memory( check_memory_misc_c_randm_seed_gui,
+			"misc.c: randm_seed_gui" );
+}
