@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr-act.c,v 1.20 2008/10/07 00:41:05 bowkenken Exp $
+* $Id: mnstr-act.c,v 1.30 2009/06/26 16:58:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -62,6 +62,7 @@
 /***************************************************************/
 
 static long	static_set_act_mnstr_giant_rat__increase_turn;
+check_memory_def( check_memory_mnstr_act_c_increase_turn )
 
 /***************************************************************
 * ƥåѿꥻå
@@ -619,6 +620,8 @@ void	set_act_mnstr_giant_rat( mnstr_t *p )
 			increase_turn = get_turn();
 		}
 	}
+
+	static_set_act_mnstr_giant_rat__increase_turn = increase_turn;
 }
 
 /*  */
@@ -754,7 +757,7 @@ void	set_act_mnstr_gargoyle( mnstr_t *p )
 
 		/* Ṳ̄ͤˤ */
 		flg_map = dun->map.obj.flg[p->y][p->x];
-		dun->map.obj.flg[p->y][p->x] |= FLG_MAP_OBJ_PASS;
+		dun->map.obj.flg[p->y][p->x] |= FLG_MAP_OBJ_LOOK;
 
 		/* СܤƤ뤫å */
 		mark = mnstr_mark_mbr_adjoin( p );
@@ -766,7 +769,9 @@ void	set_act_mnstr_gargoyle( mnstr_t *p )
 		if( mark != NULL ){
 			dun->map.obj.mjr[p->y][p->x] = FACE_MJR_FLOOR;
 			dun->map.obj.mnr[p->y][p->x] = FACE_MNR_FLOOR;
-			dun->map.obj.flg[p->y][p->x] = FLG_MAP_OBJ_PASS;
+			dun->map.obj.flg[p->y][p->x]
+					= (FLG_MAP_OBJ_PASS
+					| FLG_MAP_OBJ_LOOK);
 		}
 	}
 
@@ -849,7 +854,16 @@ void	set_act_mnstr_succubus( mnstr_t *p )
 
 void	set_act_mnstr_exel( mnstr_t *p )
 {
-	set_act_mnstr_exeler( p );
+	if( p == NULL )
+		return;
+
+	if( get_last_scene() != LAST_SCENE_N_EXEL_BATTLE ){
+		p->stat |= FLG_STAT_IRON_BODY;
+		p->abl.hp.n = p->abl.hp.max;
+	} else {
+		p->stat &= ~FLG_STAT_IRON_BODY;
+		set_act_mnstr_std( p );
+	}
 }
 
 /***************************************************************
@@ -859,28 +873,16 @@ void	set_act_mnstr_exel( mnstr_t *p )
 
 void	set_act_mnstr_exeler( mnstr_t *p )
 {
-	long	x, y;
-
 	if( p == NULL )
 		return;
 
-	x = p->x;
-	y = p->y;
-	clr_map_chr( p );
-
-	p->work.hyper_boss++;
-	p->work.hyper_boss %= (HYPER_BOSS_PERFECT + 1);
-	if( p->work.hyper_boss <= HYPER_BOSS_NULL )
-		p->work.hyper_boss = HYPER_BOSS_NULL + 1;
-
-	p->work.flg_hyper_boss = !p->work.flg_hyper_boss;
-
-	p->x = x;
-	p->y = y;
-	set_map_chr( p );
-
-	/**/
-//@@@	set_act_mnstr_std( p );
+	if( get_last_scene() != LAST_SCENE_N_EXELER_BATTLE ){
+		p->stat |= FLG_STAT_IRON_BODY;
+		p->abl.hp.n = p->abl.hp.max;
+	} else {
+		p->stat &= ~FLG_STAT_IRON_BODY;
+		set_act_mnstr_std( p );
+	}
 }
 
 /***************************************************************
@@ -890,6 +892,28 @@ void	set_act_mnstr_exeler( mnstr_t *p )
 
 void	set_act_mnstr_xex( mnstr_t *p )
 {
-//@@@	set_act_mnstr_std( p );
+	if( p == NULL )
+		return;
+
+	p->stat |= FLG_STAT_IRON_BODY;
+	p->abl.hp.n = p->abl.hp.max;
 }
 
+/***************************************************************
+* ȥƥΥ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
+void	set_act_mnstr_xx( mnstr_t *p )
+{
+}
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_mnstr_act_c( void )
+{
+	check_memory( check_memory_mnstr_act_c_increase_turn,
+			"mnstr-act.c: increase_turn" );
+}
