@@ -72,8 +72,8 @@ mnstr_tab_t	*get_towner_tab_rand( void );
 long	get_mnstr_lev_tab_max( void );
 mnstr_lev_tab_t	*get_mnstr_lev_tab( mnstr_kind_t mnstr_kind, long dun_lev );
 void	ins_ls_mnstr( mnstr_t *ls, mnstr_t *p );
-long	calc_mnstr_exp( mnstr_t *p, long dun_lev );
-long	calc_mnstr_exp_sub( mnstr_t *p, long dun_lev );
+long	calc_mnstr_exp( mnstr_kind_t mnstr_kind, long dun_lev );
+long	calc_mnstr_exp_sub( mnstr_kind_t mnstr_kind, long dun_lev );
 long	calc_mnstr_abl_lev( long dun_lev, abl_kind_t k, mnstr_tab_t *tab );
 rate_t	calc_mnstr_group_rate( long group_n );
 gold_t	calc_mnstr_gold( long dun_lev, rate_t rate );
@@ -95,6 +95,7 @@ mnstr_t	*get_mnstr_randm2( long x, long y );
 mnstr_kind_t	get_mnstr_kind_from_face( char mjr, char mnr );
 mnstr_t	*get_last_boss( last_boss_kind_t kind );
 mnstr_t	*get_mnstr_used( void );
+void	check_memory_mnstr_c( void );
 
 #ifdef __cplusplus
 }
