@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.203 2008/10/07 08:29:52 bowkenken Exp $
+* $Id: mnstr.c,v 1.227 2009/07/02 22:29:45 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -63,13 +63,17 @@
 
 /* ס */
 static mnstr_t	mnstr_buf[MNSTR_MAX_N];
+check_memory_def( check_memory_mnstr_c_mnstr_buf )
 /* ƺ */
 static mnstr_t	mnstr_used;
+check_memory_def( check_memory_mnstr_c_mnstr_used )
 /* ̤ */
 static mnstr_t	mnstr_free;
+check_memory_def( check_memory_mnstr_c_mnstr_free )
 
 /* 饹ܥ */
 static mnstr_t	*g_last_boss[LAST_BOSS_KIND_MAX_N];
+check_memory_def( check_memory_mnstr_c_g_last_boss )
 
 /***************************************************************
 * 󥹥Υǡơ֥
@@ -180,7 +184,7 @@ void	init_mnstr( void )
 
 	for( i = MNSTR_KIND_NULL + 1; i < MNSTR_KIND_MAX_N; i++ ){
 		if( !ls_flg_chk_mnstr_kind[i] ){
-			name = get_mnstr_name( i );
+			name = get_mnstr_name( (mnstr_kind_t)i );
 			print_msg( FLG_MSG_DEBUG,
 					MSG_ERR_MNSTR_LEV_TAB_NOT_DEF,
 					name );
@@ -332,7 +336,7 @@ void	new_mnstr( mnstr_t *mnstr )
 	mnstr->act.dflt_kind_mnstr
 			= ACT_KIND_MNSTR_FIGHT;
 	str_nz_cpy( mnstr->act.dflt_msg_mnstr,
-			MSG_MENU_MARK_FIGHT, ACT_MSG_MAX_LEN );
+			MSG_MENU_MARK_FIGHT, ACT_MSG_MAX_BYTE );
 	clr_chr_trgt_act( mnstr, TRUE );
 	mnstr->pre_act = mnstr->act;
 
@@ -353,6 +357,17 @@ void	new_mnstr( mnstr_t *mnstr )
 		mnstr->abl.lev[i].add = 0;
 		mnstr->abl.exp[i].n = mnstr->abl.exp[i].max;
 	}
+	for( ; i < ABL_SKILL_MAX_N; i++ ){
+		lev = 0;
+
+		mnstr->abl.lev[i].max = lev;
+		mnstr->abl.exp[i].max = calc_lev_to_exp(
+				lev, (abl_kind_t)i );
+
+		mnstr->abl.lev[i].n = mnstr->abl.lev[i].max;
+		mnstr->abl.lev[i].add = 0;
+		mnstr->abl.exp[i].n = mnstr->abl.exp[i].max;
+	}
 	mnstr->abl.hp.max = calc_max_hp( mnstr );
 	mnstr->abl.mp.max = calc_max_mp( mnstr );
 	mnstr->abl.hp.n = mnstr->abl.hp.max;
@@ -555,7 +570,7 @@ mnstr_t	*make_mnstr_alloc(
 
 	new_mnstr( p );
 
-	str_nz_cpy( p->name, tab->name, MNSTR_NAME_MAX_LEN );
+	str_nz_cpy( p->name, tab->name, MNSTR_NAME_MAX_BYTE );
 	p->x = MAP_DEL_X;
 	p->y = MAP_DEL_Y;
 	p->pre_x = p->x;
@@ -731,13 +746,24 @@ bool_t	make_mnstr_special( mnstr_t *p, long dun_lev )
 		break;
 	case MNSTR_KIND_EXEL:
 		g_last_boss[LAST_BOSS_KIND_EXEL] = p;
+
+		p->flg_chr |= FLG_CHR_HYPER;
+		p->work.hyper_boss = HYPER_BOSS_NORMAL;
+		p->work.flg_hyper_boss = FALSE;
 		break;
 	case MNSTR_KIND_EXELER:
 		g_last_boss[LAST_BOSS_KIND_EXELER] = p;
+
+		p->flg_chr |= FLG_CHR_HYPER;
+		p->work.hyper_boss = HYPER_BOSS_NORMAL;
+		p->work.flg_hyper_boss = FALSE;
 		break;
 	case MNSTR_KIND_XEX:
 		g_last_boss[LAST_BOSS_KIND_XEX] = p;
 		break;
+	case MNSTR_KIND_XX:
+		g_last_boss[LAST_BOSS_KIND_XX] = p;
+		break;
 	}
 
 	return ret;
@@ -1331,21 +1357,23 @@ bool_t	chk_auto_door_mnstr( mnstr_t *p, long x1, long y1, long x2, long y2 )
 bool_t	chk_auto_door_mnstr_open( mnstr_t *p, long x, long y )
 {
 	dun_t	*dun = get_dun();
+	door_t	*dr;
 
 	if( p == NULL )
 		return FALSE;
 	if( !clip_pos( x, y ) )
 		return FALSE;
 
-	if( dun->map.obj.mjr[y][x] == FACE_MJR_DOOR_CLOSE ){
-		door_t	*dr;
+	if( dun->map.obj.mjr[y][x] != FACE_MJR_DOOR_CLOSE )
+		return FALSE;
+	if( chk_flg( dun->map.obj.flg[y][x], FLG_MAP_OBJ_LOOK_WALL ) )
+		return FALSE;
 
-		dr = get_door( x, y );
-		if( dr != NULL )
-			return chr_open_door( p, dr->n );
-	}
+	dr = get_door( x, y );
+	if( dr == NULL )
+		return FALSE;
 
-	return FALSE;
+	return chr_open_door( p, dr->n );
 }
 
 /***************************************************************
@@ -1359,23 +1387,23 @@ bool_t	chk_auto_door_mnstr_open( mnstr_t *p, long x, long y )
 bool_t	chk_auto_door_mnstr_break( mnstr_t *p, long x, long y )
 {
 	dun_t	*dun = get_dun();
-	char	c;
+	door_t	*dr;
 
 	if( p == NULL )
 		return FALSE;
 	if( !clip_pos( x, y ) )
 		return FALSE;
 
-	c = dun->map.obj.mjr[y][x];
-	if( (c == FACE_MJR_DOOR_CLOSE) || (c == FACE_MJR_DOOR_OPEN) ){
-		door_t	*dr;
+	if( dun->map.obj.mjr[y][x] != FACE_MJR_DOOR_CLOSE )
+		return FALSE;
+	if( chk_flg( dun->map.obj.flg[y][x], FLG_MAP_OBJ_LOOK_WALL ) )
+		return FALSE;
 
-		dr = get_door( x, y );
-		if( dr != NULL )
-			return chr_break_door( p, dr->n );
-	}
+	dr = get_door( x, y );
+	if( dr == NULL )
+		return FALSE;
 
-	return FALSE;
+	return chr_break_door( p, dr->n );
 }
 
 /***************************************************************
@@ -1408,6 +1436,7 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 	dun_t	*dun;
 	party_t	*pty;
 	bool_t	flg_pre_find;
+	flg_map_t	flg;
 	long	bx, by;
 	long	ex, ey;
 	long	x, y;
@@ -1424,13 +1453,13 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 
 	flg_pre_find = chk_flg( p->flg_map, FLG_MAP_CHR_FIND );
 	p->flg_map &= ~FLG_MAP_CHR_FIND;
+	flg = FLG_NULL;
 	for( i = 0; i < MBR_MAX_N; i++ ){
-
 		/* ȯ? */
 		if( chk_find_chr( pty->mbr[i], p ) ){
-
 			/* ȯޥåסե饰ΩƤ */
 			p->flg_map |= FLG_MAP_CHR_FIND;
+			flg = FLG_MAP_CHR_FIND;
 
 			break;
 		}
@@ -1454,7 +1483,7 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 			if( !clip_pos( x, y ) )
 				continue;
 
-				dun->map.chr.flg[y][x] = p->flg_map;
+				dun->map.chr.flg[y][x] |= flg;
 		}
 	}
 
@@ -1491,6 +1520,7 @@ void	set_flg_work_find_mbr( mnstr_t *p, bool_t flg )
 			chk_boss_find_mbr( p );
 
 		p->work.flg |= FLG_WORK_FIND_MBR;
+		set_flg_mnstr_find_mbr( TRUE );
 	} else {
 		p->work.flg &= ~(FLG_WORK_FIND_MBR);
 	}
@@ -1505,16 +1535,17 @@ void	chk_boss_find_mbr( mnstr_t *p )
 {
 	if( p == NULL )
 		return;
-	if( p->kind != CHR_KIND_MNSTR )
-		return;
-	if( p->mnstr_tab == NULL )
-		return;
-	if( !(p->mnstr_tab->flg_boss) )
+	if( !is_boss( p ) )
 		return;
 
+	set_flg_boss_find_mbr( TRUE );
+
 	curs_attrset_chr( p, +1, TRUE );
 	print_msg( FLG_NULL, MSG_BOSS_FIND_MBR, p->name );
 	curs_attrset_dflt();
+
+	draw_words( NULL, MSG_BOSS_FIND_MBR, p->name );
+	redraw_all();
 }
 
 /***************************************************************
@@ -1557,17 +1588,39 @@ void	die_mnstr_drop_item( mnstr_t *p )
 /***************************************************************
 * 󥹥ν
 * mnstr_t *p : 󥹥
+* bool_t flg_msg : åɸ뤫?
 ***************************************************************/
 
-void	die_mnstr( mnstr_t *p )
+void	die_mnstr( mnstr_t *p, bool_t flg_msg )
 {
 	if( p == NULL )
 		return;
+	if( p->kind != CHR_KIND_MNSTR )
+		return;
 
 	if( is_pet( p ) ){
-		die_pet( p );
+		die_pet( p, flg_msg );
 		return;
 	}
+
+	if( !flg_msg )
+		return;
+
+	if( is_xx( p ) ){
+		call_game_sound_play(
+				SOUND_KIND_FIGHT_DIE_MONSTER_BOSS_LAST,
+				1 );
+	} else if( p->mnstr_kind == MNSTR_KIND_XEX ){
+		;
+	} else if( is_boss( p ) ){
+		call_game_sound_play(
+				SOUND_KIND_FIGHT_DIE_MONSTER_BOSS,
+				1 );
+	} else {
+		call_game_sound_play(
+				SOUND_KIND_FIGHT_DIE_MONSTER,
+				1 );
+	}
 }
 
 /***************************************************************
@@ -1577,6 +1630,22 @@ void	die_mnstr( mnstr_t *p )
 ***************************************************************/
 
 bool_t	chk_die_boss( mnstr_t *p )
+{
+	if( !is_boss( p ) )
+		return FALSE;
+
+	die_boss( p );
+
+	return TRUE;
+}
+
+/***************************************************************
+* 󥹥ܥĴ٤
+* mnstr_t *p : 󥹥
+* return : ܥ?
+***************************************************************/
+
+bool_t	is_boss( mnstr_t *p )
 {
 	if( p == NULL )
 		return FALSE;
@@ -1587,7 +1656,51 @@ bool_t	chk_die_boss( mnstr_t *p )
 	if( !(p->mnstr_tab->flg_boss) )
 		return FALSE;
 
-	die_boss( p );
+	return TRUE;
+}
+
+/***************************************************************
+* 󥹥饹ܥĴ٤
+* mnstr_t *p : 󥹥
+* return : 饹ܥ?
+***************************************************************/
+
+bool_t	is_last_boss( mnstr_t *p )
+{
+	mnstr_t	*boss;
+	long	i;
+
+	if( p == NULL )
+		return FALSE;
+	if( p->kind != CHR_KIND_MNSTR )
+		return FALSE;
+
+	for( i = LAST_BOSS_KIND_NULL; i < LAST_BOSS_KIND_MAX_N; i++ ){
+		boss = get_last_boss( (last_boss_kind_t)i );
+		if( boss == NULL )
+			continue;
+
+		if( p->mnstr_kind == boss->mnstr_kind )
+			return TRUE;
+	}
+
+	return FALSE;
+}
+
+/***************************************************************
+* 󥹥 XX Ĵ٤
+* mnstr_t *p : 󥹥
+* return : XX ?
+***************************************************************/
+
+bool_t	is_xx( mnstr_t *p )
+{
+	if( p == NULL )
+		return FALSE;
+	if( p->kind != CHR_KIND_MNSTR )
+		return FALSE;
+	if( p->mnstr_kind != MNSTR_KIND_XX )
+		return FALSE;
 
 	return TRUE;
 }
@@ -1626,9 +1739,16 @@ void	die_boss( mnstr_t *m )
 	}
 
 	if( boss_n <= 1 ){
-		/* ܥݤ鳬ʤ */
+		/* å */
+		draw_words( NULL, MSG_FIGHT_KILL_BOSS, m->name );
 
+		/* ܥݤ鳬ʤ */
 		make_stairs( m->x, m->y, FACE_MJR_STAIRS_DOWN );
+
+		/* ƥ */
+		mnstr_drop_key_item( p );
+
+		redraw_all();
 	}
 }
 
@@ -1764,6 +1884,41 @@ void	mnstr_drop_item( mnstr_t *p )
 	}
 }
 
+/***************************************************************
+* ܥ󥹥˥ƥ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
+void	mnstr_drop_key_item( mnstr_t *p )
+{
+	dun_t	*dun = get_dun();
+	star_drop_kind_t	kind;
+	static char	str[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
+	const long	max_len = SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8;
+
+	if( p == NULL )
+		return;
+	if( p->mnstr_tab == NULL )
+		return;
+
+	kind = (star_drop_kind_t)
+			(labs( dun->lev ) / DUN_LEV_BOSS - 1);
+	kind = (star_drop_kind_t)
+			((kind + BOOT_UNIT_MAX_N) % BOOT_UNIT_MAX_N);
+
+	if( chk_key_item( kind ) )
+		return;
+
+	set_key_item( kind, TRUE );
+
+	sn_printf( str, max_len, MSG_GET_KEY_ITEM,
+			get_key_item_name( kind ) );
+
+	print_msg( FLG_NULL, MSG_S, str );
+	draw_words( NULL, str );
+	redraw_all();
+}
+
 /***************************************************************
 * ƤΥ󥹥ȯȲĻξ֤ˤ
 ***************************************************************/
@@ -2132,6 +2287,9 @@ mnstr_lev_tab_t	*get_mnstr_lev_tab( mnstr_kind_t mnstr_kind, long dun_lev )
 	mnstr_lev_tab_t	*tab;
 	long	i, max_i, n;
 
+	if( mnstr_kind == MNSTR_KIND_NULL )
+		return NULL;
+
 	tab = NULL;
 	n = 0;
 	max_i = sizeof( mnstr_lev_tab ) / sizeof( mnstr_lev_tab[0] );
@@ -2194,89 +2352,15 @@ void	ins_ls_mnstr( mnstr_t *ls, mnstr_t *p )
 	ls->prev = p;
 }
 
-/***************************************************************
-* 󥹥˷иͤͿ
-* chr_t *chr : 󥹥
-* long exp : и
-* bool_t flg_print_lev : ٥Υåɽ뤫
-***************************************************************/
-
-void	exp_chr_mnstr(
-	chr_t *chr,
-	long exp,
-	bool_t flg_set_max,
-	bool_t flg_print_lev
-)
-{
-	long	left_exp;
-	rate_t	abl_sum;
-	long	left_k, k;
-	long	left_n;
-
-	if( chr == NULL )
-		return;
-	if( chr->mnstr_tab == NULL )
-		return;
-
-	left_exp = exp;
-	left_n = 0;
-	left_k = 0;
-
-	abl_sum = 0;
-	for( k = 0; k < ABL_KIND_MAX_N; k++ )
-		abl_sum += chr->mnstr_tab->abl_lev_rate[k];
-	if( abl_sum <= 0 )
-		return;
-
-	for( k = 0; k < ABL_KIND_MAX_N; k++ ){
-		rate_t	abl_rate;
-		long	e;
-
-		abl_rate = chr->mnstr_tab->abl_lev_rate[k];
-		if( abl_rate == 0 )
-			continue;
-
-		e = exp * abl_rate / abl_sum;
-		chr->abl.exp[k].n += e;
-
-		if( chr->abl.exp[k].n < 0 )
-			chr->abl.exp[k].n = 0;
-		if( chr->abl.exp[k].n > EXP_MAX )
-			chr->abl.exp[k].n = EXP_MAX;
-		if( flg_set_max )
-			chr->abl.exp[k].max = chr->abl.exp[k].n;
-		if( chr->abl.exp[k].max < chr->abl.exp[k].n )
-			chr->abl.exp[k].max = chr->abl.exp[k].n;
-
-		left_exp -= e;
-		left_n++;
-		if( per_randm( left_n ) )
-			left_k = k;
-	}
-
-	chr->abl.exp[left_k].n += left_exp;
-
-	if( chr->abl.exp[left_k].n < 0 )
-		chr->abl.exp[left_k].n = 0;
-	if( chr->abl.exp[left_k].n > EXP_MAX )
-		chr->abl.exp[left_k].n = EXP_MAX;
-	if( flg_set_max )
-		chr->abl.exp[left_k].max = chr->abl.exp[left_k].n;
-	if( chr->abl.exp[left_k].max < chr->abl.exp[left_k].n )
-		chr->abl.exp[left_k].max = chr->abl.exp[left_k].n;
-
-	chk_lev_up( chr, FALSE, flg_print_lev );
-}
-
 /***************************************************************
 * 󥹥ݤηиͤ׻
 * 󥹥Υ٥Υ롼פθ
-* mnstr_t *p : 󥹥
+* mnstr_kind_t mnstr_kind : 󥹥μ
 * long dun_lev : 󥸥γ
 * return : и
 ***************************************************************/
 
-long	calc_mnstr_exp( mnstr_t *p, long dun_lev )
+long	calc_mnstr_exp( mnstr_kind_t mnstr_kind, long dun_lev )
 {
 	long	dun_lev_max, dun_lev_mod;
 	long	lev_mul;
@@ -2290,8 +2374,8 @@ long	calc_mnstr_exp( mnstr_t *p, long dun_lev )
 	if( lev_mul < 0 )
 		lev_mul = 0;
 
-	exp_max = calc_mnstr_exp_sub( p, dun_lev_max );
-	exp_mod = calc_mnstr_exp_sub( p, dun_lev_mod );
+	exp_max = calc_mnstr_exp_sub( mnstr_kind, dun_lev_max );
+	exp_mod = calc_mnstr_exp_sub( mnstr_kind, dun_lev_mod );
 	exp = (exp_max * lev_mul) + exp_mod;
 
 	return exp;
@@ -2299,20 +2383,20 @@ long	calc_mnstr_exp( mnstr_t *p, long dun_lev )
 
 /***************************************************************
 * 󥹥ݤηиͤ׻
-* mnstr_t *p : 󥹥
+* mnstr_kind_t mnstr_kind : 󥹥μ
 * long dun_lev : 󥸥γ
 * return : и
 ***************************************************************/
 
-long	calc_mnstr_exp_sub( mnstr_t *p, long dun_lev )
+long	calc_mnstr_exp_sub( mnstr_kind_t mnstr_kind, long dun_lev )
 {
+	mnstr_tab_t	*tab;
 	long	lev;
 	long	exp;
 
-	if( p == NULL )
-		return 1;
-	if( p->mnstr_tab == NULL )
-		return 1;
+	tab = NULL;
+	if( mnstr_kind != MNSTR_KIND_NULL )
+		tab = get_mnstr_tab( mnstr_kind, dun_lev );
 
 	/* µܤγؤ׻ */
 
@@ -2327,12 +2411,15 @@ long	calc_mnstr_exp_sub( mnstr_t *p, long dun_lev )
 
 	/*  */
 
-	exp += exp * p->mnstr_tab->exp / _100_PERCENT;
+	if( tab != NULL )
+		exp += exp * tab->exp / _100_PERCENT;
 
 	/* ο */
 
-	exp *= calc_mnstr_group_rate( p->mnstr_tab->group );
-	exp /= _100_PERCENT;
+	if( tab != NULL ){
+		exp *= calc_mnstr_group_rate( tab->group );
+		exp /= _100_PERCENT;
+	}
 
 	/**/
 
@@ -2482,6 +2569,11 @@ mnstr_t	*get_mnstr( long x, long y )
 	if( pet != NULL )
 		return pet;
 
+	/* 饹ܥĴ٤ */
+
+	if( chk_xx_pos( x, y ) )
+		return get_last_boss( LAST_BOSS_KIND_XX );
+
 	return NULL;
 }
 
@@ -2949,3 +3041,18 @@ mnstr_t	*get_mnstr_used( void )
 	return &mnstr_used;
 }
 
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_mnstr_c( void )
+{
+	check_memory( check_memory_mnstr_c_mnstr_buf,
+			"mnstr.c: mnstr_buf" );
+	check_memory( check_memory_mnstr_c_mnstr_used,
+			"mnstr.c: mnstr_used" );
+	check_memory( check_memory_mnstr_c_mnstr_free,
+			"mnstr.c: mnstr_free" );
+	check_memory( check_memory_mnstr_c_g_last_boss,
+			"mnstr.c: g_last_boss" );
+}
