@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.h,v 1.35 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: mnstr.h,v 1.39 2009/01/09 09:46:09 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MNSTR_H
@@ -104,4 +104,15 @@ typedef struct {
 	long	min_lev, max_lev;
 } mnstr_lev_tab_t;
 
+/* 饹ܥμ */
+
+typedef enum {
+	LAST_BOSS_KIND_NULL,
+	LAST_BOSS_KIND_EXEL,
+	LAST_BOSS_KIND_EXELER,
+	LAST_BOSS_KIND_XEX,
+	LAST_BOSS_KIND_XX,
+	LAST_BOSS_KIND_MAX_N,
+} last_boss_kind_t;
+
 #endif	/* MNSTR_H */
