@@ -19,7 +19,12 @@ void	new_mbr(
 	race_t race, sex_t sex, long class_n, long ls_mbr_n
 );
 bool_t	reset_mbr_resi( mbr_t *mbr );
-void	set_mbr_dir( void );
+void	reset_mbr_dir( void );
+void	reset_square_mbr_ind_pos( void );
+void	set_square_mbr_ind_pos( long mbr_n, long x, long y );
+void	get_square_mbr_abs_pos( long mbr_n, long *x, long *y );
+void	get_square_mbr_map_pos( long mbr_n, long *x, long *y );
+void	appear_party_auto( void );
 void	appear_party( void );
 bool_t	appear_party_randm( void );
 bool_t	appear_party_srch( void );
@@ -38,7 +43,8 @@ bool_t	chk_party_no_mbr( bool_t flg_enter_bar );
 void	chk_trap_party( void );
 bool_t	chk_auto_mnstr( mbr_t *mbr, long x1, long y1, long x2, long y2 );
 bool_t	chk_auto_door_mbr( mbr_t *mbr, long x1, long y1, long x2, long y2 );
-void	die_mbr( mbr_t *mbr, bool_t flg_chk_game_over );
+bool_t	chk_auto_door_mbr_sub( mbr_t *mbr, long x, long y );
+void	die_mbr( mbr_t *mbr, bool_t flg_msg, bool_t flg_chk_game_over );
 bool_t	chk_can_act_mbr( mbr_t *p );
 bool_t	set_mbr_act_auto_mnstr( mbr_t *mbr, long x, long y );
 void	mbr_peep_door( mbr_t *mbr, long dr_n );
@@ -52,6 +58,7 @@ gold_t	get_party_gold( void );
 void	add_party_gold( gold_t gold );
 gold_t	sub_party_gold( gold_t gold );
 void	exp_party( long exp, bool_t flg_set_max, bool_t flg_draw );
+long	get_mbr_race_exp( mbr_t *mbr, long exp, abl_kind_t abl );
 void	remove_mbr( mbr_t *mbr );
 mbr_t	*get_mbr_nearest( long x, long y );
 mbr_t	*get_mbr_near( long x, long y );
@@ -70,6 +77,7 @@ char	*get_race_str_sub( race_t *race );
 char	*get_race_name( race_t *race );
 bool_t	chk_not_exist_all_mbr( void );
 mbr_t	**get_ls_mbr( void );
+mbr_t	*get_ls_mbr_tail( void );
 party_t	*get_party( void );
 long	get_mbr_n( long x, long y );
 mbr_t	*get_mbr( long x, long y );
@@ -84,9 +92,10 @@ void	arrange_class_1( long class_n, long d );
 void	arrange_class( long class_n, long d );
 square_t	*get_square_mbr( void );
 void	set_square_mbr( square_t *sq );
-void	get_square_pos( long *x, long *y );
-void	set_square_pos( long x, long y );
+void	get_square_pos( long *x, long *y, bool_t flg_pre );
+void	set_square_pos( long x, long y, bool_t flg_pre );
 void	unset_square_pos( void );
+void	check_memory_party_c( void );
 
 #ifdef __cplusplus
 }
