@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.236 2009/06/23 02:02:35 bowkenken Exp $
+* $Id: party.c,v 1.238 2009/07/04 08:01:54 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -62,8 +62,11 @@
 ***************************************************************/
 
 static mbr_t	*ls_mbr[LS_MBR_MAX_N + 1];
+check_memory_def( check_memory_party_c_ls_mbr )
 static mbr_t	ls_mbr_buf[LS_MBR_MAX_N + 1];
+check_memory_def( check_memory_party_c_ls_mbr_buf )
 static party_t	party;
+check_memory_def( check_memory_party_c_party )
 
 static long	abl_init[MAIN_RACE_MAX_N][ABL_KIND_MAX_N] = {
 
@@ -118,6 +121,7 @@ static long	abl_init[MAIN_RACE_MAX_N][ABL_KIND_MAX_N] = {
 		0, 0, 0, 0,
 	},
 };
+check_memory_def( check_memory_party_c_abl_init )
 
 static rate_t	resi_init[MAIN_RACE_MAX_N][RESI_KIND_MAX_N] = {
 	/* KNOC,SLAS,STIN,HEAT,COLD,MIND,ACID,ELEC,POIS, */
@@ -132,6 +136,7 @@ static rate_t	resi_init[MAIN_RACE_MAX_N][RESI_KIND_MAX_N] = {
 /* MAIN_RACE_VIVID */
 	{    90,  90,  90, 100, 100, 200, 100, 100, 100 },
 };
+check_memory_def( check_memory_party_c_resi_init )
 
 static stomach_t	ave_stomach[MAIN_RACE_MAX_N] = {
 #if	0
@@ -149,6 +154,7 @@ typedef struct {
 	{ 100, 200, 25, 0, 70, 30 },	/* MAIN_RACE_DWARF, */
 	{ 100, 180, 25, 0, 70, 30 },	/* MAIN_RACE_VIVID, */
 };
+check_memory_def( check_memory_party_c_ave_stomach )
 
 /* class */
 
@@ -2733,23 +2739,31 @@ long	get_mbr_race_exp( mbr_t *mbr, long exp, abl_kind_t abl )
 
 void	remove_mbr( mbr_t *mbr )
 {
-	long	i;
 	long	mbr_n, ls_mbr_n;
-	mbr_t	*tmp_mbr, *p;
+	mbr_t	*p;
 
 	if( mbr == NULL )
 		return;
 
+	/* ꥹȤ򤺤餹 */
+
+	menu_bar_arrange( mbr, +1 );
+	mbr = get_ls_mbr_tail();
+	if( mbr == NULL )
+		return;
+
+	/**/
+
 	mbr_n = mbr->mbr_n;
 	ls_mbr_n = mbr->ls_mbr_n;
 
-	/**/
+	/* ƥǡ */
 
 	remove_cast_tab( ls_mbr_n );
 	remove_auto_mark_mbr( ls_mbr_n );
 	remove_mbr_del_item( ls_mbr_n );
 
-	/* ls_mbr */
+	/* mark */
 
 	p = ls_mbr[ls_mbr_n];
 	clr_map_chr( p );
@@ -2766,17 +2780,10 @@ void	remove_mbr( mbr_t *mbr )
 	if( mbr_n != MBR_N_NOT_JOIN )
 		party.mbr[mbr_n] = ls_mbr[LS_MBR_NULL];
 
-	/* ꥹȤ򤺤餹 */
+	/* ls_mbr */
 
-	tmp_mbr = ls_mbr[ls_mbr_n];
-	for( i = ls_mbr_n; i < LS_MBR_MAX_N - 1; i++ ){
-		ls_mbr[i] = ls_mbr[i + 1];
-		ls_mbr[i]->ls_mbr_n--;
-	}
-	ls_mbr[i] = tmp_mbr;
-
-	ls_mbr[i]->mbr_n = MBR_N_NOT_JOIN;
-	ls_mbr[i]->stat |= FLG_STAT_NOT_EXIST;
+	ls_mbr[ls_mbr_n]->mbr_n = MBR_N_NOT_JOIN;
+	ls_mbr[ls_mbr_n]->stat |= FLG_STAT_NOT_EXIST;
 }
 
 /**/
@@ -3320,6 +3327,24 @@ mbr_t	**get_ls_mbr( void )
 
 /**/
 
+mbr_t	*get_ls_mbr_tail( void )
+{
+	long	i;
+
+	for( i = LS_MBR_MAX_N - 1; i >= 0; i-- ){
+		if( ls_mbr[i] == NULL )
+			continue;
+		if( chk_flg( ls_mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
+			continue;
+
+		return ls_mbr[i];
+	}
+
+	return NULL;
+}
+
+/**/
+
 party_t	*get_party( void )
 {
 	return &party;
@@ -3629,3 +3654,22 @@ void	unset_square_pos( void )
 
 /**/
 
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_party_c( void )
+{
+	check_memory( check_memory_party_c_ls_mbr,
+			"party.c: ls_mbr" );
+	check_memory( check_memory_party_c_ls_mbr_buf,
+			"party.c: ls_mbr_buf" );
+	check_memory( check_memory_party_c_party,
+			"party.c: party" );
+	check_memory( check_memory_party_c_abl_init,
+			"party.c: abl_init" );
+	check_memory( check_memory_party_c_resi_init,
+			"party.c: resi_init" );
+	check_memory( check_memory_party_c_ave_stomach,
+			"party.c: ave_stomach" );
+}
